Index: src/objects.h |
diff --git a/src/objects.h b/src/objects.h |
index e2fac8ef9f128a765fb50d2024a47773a3b7ba2b..75cff5759dc8feeff72af3c80e84b7cc9811b8f0 100644 |
--- a/src/objects.h |
+++ b/src/objects.h |
@@ -1740,9 +1740,9 @@ class HeapObject: public Object { |
// Returns the heap object's size in bytes |
inline int Size(); |
- // Returns true if this heap object may contain pointers to objects in new |
- // space. |
- inline bool MayContainNewSpacePointers(); |
+ // Returns true if this heap object may contain raw values, i.e., values that |
+ // look like pointers to heap objects. |
+ inline bool MayContainRawValues(); |
// Given a heap object's map pointer, returns the heap size in bytes |
// Useful when the map pointer field is used for other purposes. |